summaryrefslogtreecommitdiffstats
path: root/mga-bg-res/mga-bg-res.sh
diff options
context:
space:
mode:
Diffstat (limited to 'mga-bg-res/mga-bg-res.sh')
-rwxr-xr-xmga-bg-res/mga-bg-res.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/mga-bg-res/mga-bg-res.sh b/mga-bg-res/mga-bg-res.sh
index 74a6371..294f09d 100755
--- a/mga-bg-res/mga-bg-res.sh
+++ b/mga-bg-res/mga-bg-res.sh
@@ -12,9 +12,9 @@ if [ -e /usr/sbin/monitor-edid -a -z "$LOCAL_INSTALL" ]; then
res=$(expr "$res" : '.*"\(.*\)".*') # isolate the resolution
fi
# If the previous method did not work, default to 4:3 aspect ratio (e.g. 1024x768)
if [ -z $res ]; then
- res="1600x1200"
+ res="1920x1080"
fi
# Check if the symlink is already good
@@ -12,9 +12,9 @@ if [ -e /usr/sbin/monitor-edid -a -z "$LOCAL_INSTALL" ]; then
res=$(expr "$res" : '.*"\(.*\)".*') # isolate the resolution
fi
-# If the previous method did not work, default to 4:3 aspect ratio (e.g. 1024x768)
+# If the previous method did not work, default to 16:9 aspect ratio (e.g. 1920x1080)
if [ -z $res ]; then